Index: pkg/dartino_compiler/lib/src/verbs/actions.dart |
diff --git a/pkg/fletchc/lib/src/verbs/actions.dart b/pkg/dartino_compiler/lib/src/verbs/actions.dart |
similarity index 95% |
rename from pkg/fletchc/lib/src/verbs/actions.dart |
rename to pkg/dartino_compiler/lib/src/verbs/actions.dart |
index ceb108a486dcfa7f4a430899985d68b76c9b3572..11908dc661452a9d26c151db5a0bcd17afb418d0 100644 |
--- a/pkg/fletchc/lib/src/verbs/actions.dart |
+++ b/pkg/dartino_compiler/lib/src/verbs/actions.dart |
@@ -2,7 +2,7 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-library fletchc.verbs.verbs; |
+library dartino_compiler.verbs.verbs; |
import 'infrastructure.dart' show |
AnalyzedSentence, |
@@ -110,7 +110,7 @@ class Action { |
/// |
/// Please make sure their combined documentation fit in in 80 columns by 20 |
/// lines. The default terminal size is normally 80x24. Two lines are used |
/// for the prompts before and after running fletch. Another two lines may be |
/// used to print an error message. |
const Map<String, Action> commonActions = const <String, Action>{ |
"help": helpAction, |
@@ -121,7 +121,7 @@ const Map<String, Action> commonActions = const <String, Action>{ |
/// Uncommon verbs aren't displayed in the normal help screen. |
/// |
/// These verbs are displayed when running `fletch help all`. |
const Map<String, Action> uncommonActions = const <String, Action>{ |
"attach": attachAction, |
"compile": compileAction, |
@@ -110,7 +110,7 @@ class Action { |
/// Please make sure their combined documentation fit in in 80 columns by 20 |
/// lines. The default terminal size is normally 80x24. Two lines are used |
-/// for the prompts before and after running fletch. Another two lines may be |
+/// for the prompts before and after running dartino. Another two lines may be |
/// used to print an error message. |
const Map<String, Action> commonActions = const <String, Action>{ |
@@ -121,7 +121,7 @@ const Map<String, Action> commonActions = const <String, Action>{ |
/// Uncommon verbs aren't displayed in the normal help screen. |
/// |
-/// These verbs are displayed when running `fletch help all`. |
+/// These verbs are displayed when running `dartino help all`. |
const Map<String, Action> uncommonActions = const <String, Action>{ |
"attach": attachAction, |